==> owncloud-8.2.2p3.tgz: owncloud/core/l10n/nds.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Senden der E-Mail an folgende Benutzer fehlgeschlagen: %s",
    "Preparing update" : "Bereite Aktualisierung vor",
    "Migration tests are skipped - \"update.skip-migration-test\" is activated in config.php" : "Migrierungstests werden übersprungen - \"update.skip-migration-test\" ist in der config.php aktiviert",
    "Turned on maintenance mode" : "Wartungsmodus eingeschaltet",
    "Turned off maintenance mode" : "Wartungsmodus ausgeschaltet",
    "Maintenance mode is kept active" : "Wartungsmodus wird fortgeführt",
    "Updated database" : "Datenbank wurde aktualisiert",
    "Checked database schema update" : "Datenbankschemaaktualisierung wurde geprüft",
    "Checked database schema update for apps" : "Datenbankschemaaktualisierung für Apps wurde geprüft",
    "Updated \"%s\" to %s" : "\"%s\" auf %s aktualisiert",
    "Repair warning: " : "Reparaturwarnung",
    "Repair error: " : "Reparaturfehler",
    "Set log level to debug - current level: \"%s\"" : "Protokollierungsstufe auf Debug gesetzt - Aktuelle Stufe: \"%s\"",
    "Reset log level to  \"%s\"" : "Protokollierungsstufe auf \"%s\" zurückgesetzt",
    "Following incompatible apps have been disabled: %s" : "Folgende inkompatible Apps wurden deaktiviert: %s",
    "Following apps have been disabled: %s" : "Folgende Apps wurden deaktiviert: %s",
    "Already up to date" : "Bereits aktuell",
    "File is too big" : "Datei ist zu groß",
    "Invalid file provided" : "Ungültige Datei geliefert",
    "No image or file provided" : "Kein Bild oder keine Datei geliefert",
    "Unknown filetype" : "Unbekannter Dateityp",
    "Invalid image" : "Ungültiges Bild",
    "No temporary profile picture available, try again" : "Kein flüchtiges Profilbild verfügbar, bitte versuche es noch einmal",
    "No crop data provided" : "Keine Angaben zum Zuschneiden geliefert",
    "No valid crop data provided" : "Keine gültigen Angaben zum Zuschnitt geliefert",
    "Crop is not square" : "Zuschnitt ist nicht quadratisch",
    "Sunday" : "Sonntag",
    "Monday" : "Montag",
    "Tuesday" : "Dienstag",
    "Wednesday" : "Mittwoch",
    "Thursday" : "Donnerstag",
    "Friday" : "Freitag",
    "Saturday" : "Samstag",
    "Sun." : "Son.",
    "Mon." : "Mon.",
    "Tue." : "Die.",
    "Wed." : "Mit.",
    "Thu." : "Don.",
    "Fri." : "Fre.",
    "Sat." : "Sam.",
    "Su" : "So",
    "Mo" : "Mo",
    "Tu" : "Di",
    "We" : "Mi",
    "Th" : "Do",
    "Fr" : "Fr",
    "Sa" : "Sa",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "März",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Dezember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mrz.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "Settings" : "Einstellungen",
    "Saving..." : "Speichern...",
    "seconds ago" : "vor wenigen Sekunden",
    "Couldn't send reset email. Please contact your administrator." : "E-Mail zum Zurücksetzen konnte nicht gesendet werden. Bitte wende Dich an Deinem Administrator.",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Der Link zum Zurücksetzen deines Passworts wurde an Deine E-Mailadresse geschickt. Wenn Du diesen in einer angemessenen Zeit nicht erhältst, prüfe bitte deine Spam/Junk Ordner.<br> Wenn die E-Mail dort nicht ist, wende Dich an Deinen lokalen Administrator.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Deine Dateien sind verschlüsselt. Wenn Dein Wiederherstellungsschlüssel nicht aktiviert ist, gibt es keine Möglichkeit die Daten wiederherzustellen, nachdem Dein Passwort zurückgesetzt wurde.<br /> Wenn Du nicht sicher weißt was zu tun ist, wende Dich bitte an deinen Adminstrator bevor du fortfährst.<br />Willst du wirklich fortfahren?",
    "I know what I'm doing" : "Ich weiß was ich tue",
    "Password can not be changed. Please contact your administrator." : "Das Passwort kann nicht geändert werden. Bitte wende Dich an Deinen Administrator.",
    "No" : "Nein",
    "Yes" : "Ja",
    "Choose" : "Auswählen",
    "Error loading file picker template: {error}" : "Fehler beim Laden der Vorlage zum Auswählen von Dateien: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Fehler beim Laden der Nachrichtenvorlage: {error}",
    "read-only" : "Nur Lesezugriff",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} Dateikonflikt","{count} Dateikonflikte"],
    "One file conflict" : "Ein Dateikonflikt",
    "New Files" : "Neue Dateien",
    "Already existing files" : "Bereits vorhandene Dateien",
    "Which files do you want to keep?" : "Welche Dateien willst du behalten?",
    "If you select both versions, the copied file will have a number added to its name." : "Wenn Du beide Versionen behältst, wird eine Nummer an den Namen der kopierten Datei angehängt.",
    "Cancel" : "Abbrechen",
    "Continue" : "Fortsetzen",
    "(all selected)" : "(alle ausgewählt)",
    "({count} selected)" : "({count} ausgewählt)",
    "Error loading file exists template" : "Fehler beim Laden der Vorlage \"Datei existiert\"",
    "Very weak password" : "Sehr schwaches Passwort",
    "Weak password" : "Schwaches Passwort",
    "So-so password" : "Mittelstarkes Passwort",
    "Good password" : "Gutes Passwort",
    "Strong password" : "Starkes Passwort",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Dein Webserver ist für die Dateisynchronisierung noch nicht ordentlich eingerichtet, da die WebDAV-Schnittstelle fehlerhaft scheint. ",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Dieser Server ist nicht mit dem Internet verbunden. Das bedeutet, dass manche Funktionen, wie das Einbinden von externen Speichern, Benachrichtigungen über Aktualisierungen oder die Installation von Drittanbieter Apps nicht zur Verfügung stehen. Auch der Fernzugriff auf Dateien und das Senden von Hinweis-E-Mails könnte nicht funktionieren. Wir empfehlen die Internetverbindung dieses Servers zu aktivieren, wenn Du diese Funktionen nutzen möchtest.",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Der Zugriff auf Dein Datenverzeichnis und Deine Dateien ist über das Internet vermutlich möglich. Die .htaccess-Datei greift nicht. Wir empfehlen dringend den Webserver derart zu konfigurieren, dass das Datenverzeichnis nicht mehr zugreifbar ist oder das Datenverzeichnis nach außerhalb des Dokumentenwurzelverzeichnisses des Webservers zu verschieben.",
    "Password" : "Passwort",
    "Share" : "Teilen",
    "Delete" : "Löschen",
    "Personal" : "Persönlich",
    "Username" : "Benutzername"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3.tgz: owncloud/core/l10n/nds.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Senden der E-Mail an folgende Benutzer fehlgeschlagen: %s",
    "Preparing update" : "Bereite Aktualisierung vor",
    "Turned on maintenance mode" : "Wartungsmodus eingeschaltet",
    "Turned off maintenance mode" : "Wartungsmodus ausgeschaltet",
    "Maintenance mode is kept active" : "Wartungsmodus wird fortgeführt",
    "Updated database" : "Datenbank wurde aktualisiert",
    "Checked database schema update" : "Datenbankschemaaktualisierung wurde geprüft",
    "Checked database schema update for apps" : "Datenbankschemaaktualisierung für Apps wurde geprüft",
    "Updated \"%s\" to %s" : "\"%s\" auf %s aktualisiert",
    "Repair warning: " : "Reparaturwarnung",
    "Repair error: " : "Reparaturfehler",
    "Following apps have been disabled: %s" : "Folgende Apps wurden deaktiviert: %s",
    "Already up to date" : "Bereits aktuell",
    "File is too big" : "Datei ist zu groß",
    "Invalid file provided" : "Ungültige Datei geliefert",
    "No image or file provided" : "Kein Bild oder keine Datei geliefert",
    "Unknown filetype" : "Unbekannter Dateityp",
    "Invalid image" : "Ungültiges Bild",
    "No temporary profile picture available, try again" : "Kein flüchtiges Profilbild verfügbar, bitte versuche es noch einmal",
    "No crop data provided" : "Keine Angaben zum Zuschneiden geliefert",
    "No valid crop data provided" : "Keine gültigen Angaben zum Zuschnitt geliefert",
    "Crop is not square" : "Zuschnitt ist nicht quadratisch",
    "Couldn't send reset email. Please contact your administrator." : "E-Mail zum Zurücksetzen konnte nicht gesendet werden. Bitte wende Dich an Deinem Administrator.",
    "Sunday" : "Sonntag",
    "Monday" : "Montag",
    "Tuesday" : "Dienstag",
    "Wednesday" : "Mittwoch",
    "Thursday" : "Donnerstag",
    "Friday" : "Freitag",
    "Saturday" : "Samstag",
    "Sun." : "Son.",
    "Mon." : "Mon.",
    "Tue." : "Die.",
    "Wed." : "Mit.",
    "Thu." : "Don.",
    "Fri." : "Fre.",
    "Sat." : "Sam.",
    "Su" : "So",
    "Mo" : "Mo",
    "Tu" : "Di",
    "We" : "Mi",
    "Th" : "Do",
    "Fr" : "Fr",
    "Sa" : "Sa",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "März",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Dezember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mrz.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "Settings" : "Einstellungen",
    "Saving..." : "Speichern...",
    "seconds ago" : "vor wenigen Sekunden",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Der Link zum Zurücksetzen deines Passworts wurde an Deine E-Mailadresse geschickt. Wenn Du diesen in einer angemessenen Zeit nicht erhältst, prüfe bitte deine Spam/Junk Ordner.<br> Wenn die E-Mail dort nicht ist, wende Dich an Deinen lokalen Administrator.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Deine Dateien sind verschlüsselt. Wenn Dein Wiederherstellungsschlüssel nicht aktiviert ist, gibt es keine Möglichkeit die Daten wiederherzustellen, nachdem Dein Passwort zurückgesetzt wurde.<br /> Wenn Du nicht sicher weißt was zu tun ist, wende Dich bitte an deinen Adminstrator bevor du fortfährst.<br />Willst du wirklich fortfahren?",
    "I know what I'm doing" : "Ich weiß was ich tue",
    "Password can not be changed. Please contact your administrator." : "Das Passwort kann nicht geändert werden. Bitte wende Dich an Deinen Administrator.",
    "No" : "Nein",
    "Yes" : "Ja",
    "Choose" : "Auswählen",
    "Error loading file picker template: {error}" : "Fehler beim Laden der Vorlage zum Auswählen von Dateien: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Fehler beim Laden der Nachrichtenvorlage: {error}",
    "read-only" : "Nur Lesezugriff",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} Dateikonflikt","{count} Dateikonflikte"],
    "One file conflict" : "Ein Dateikonflikt",
    "New Files" : "Neue Dateien",
    "Already existing files" : "Bereits vorhandene Dateien",
    "Which files do you want to keep?" : "Welche Dateien willst du behalten?",
    "If you select both versions, the copied file will have a number added to its name." : "Wenn Du beide Versionen behältst, wird eine Nummer an den Namen der kopierten Datei angehängt.",
    "Cancel" : "Abbrechen",
    "Continue" : "Fortsetzen",
    "(all selected)" : "(alle ausgewählt)",
    "({count} selected)" : "({count} ausgewählt)",
    "Error loading file exists template" : "Fehler beim Laden der Vorlage \"Datei existiert\"",
    "Very weak password" : "Sehr schwaches Passwort",
    "Weak password" : "Schwaches Passwort",
    "So-so password" : "Mittelstarkes Passwort",
    "Good password" : "Gutes Passwort",
    "Strong password" : "Starkes Passwort",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Dein Webserver ist für die Dateisynchronisierung noch nicht ordentlich eingerichtet, da die WebDAV-Schnittstelle fehlerhaft scheint. ",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Dieser Server ist nicht mit dem Internet verbunden. Das bedeutet, dass manche Funktionen, wie das Einbinden von externen Speichern, Benachrichtigungen über Aktualisierungen oder die Installation von Drittanbieter Apps nicht zur Verfügung stehen. Auch der Fernzugriff auf Dateien und das Senden von Hinweis-E-Mails könnte nicht funktionieren. Wir empfehlen die Internetverbindung dieses Servers zu aktivieren, wenn Du diese Funktionen nutzen möchtest.",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Der Zugriff auf Dein Datenverzeichnis und Deine Dateien ist über das Internet vermutlich möglich. Die .htaccess-Datei greift nicht. Wir empfehlen dringend den Webserver derart zu konfigurieren, dass das Datenverzeichnis nicht mehr zugreifbar ist oder das Datenverzeichnis nach außerhalb des Dokumentenwurzelverzeichnisses des Webservers zu verschieben.",
    "Error" : "Fehler",
    "Password" : "Passwort",
    "Send" : "Senden",
    "can share" : "kann teilen",
    "can edit" : "kann editieren",
    "Share" : "Teilen",
    "Delete" : "Löschen",
    "Personal" : "Persönlich",
    "Username" : "Benutzername",
    "Error loading file picker template: {error}" : "Fehler beim Laden der Vorlage zum Auswählen von Dateien: {error}",
    "Password can not be changed. Please contact your administrator." : "Das Passwort kann nicht geändert werden. Bitte wende Dich an Deinen Administrator."
},
"nplurals=2; plural=(n != 1);");
